django-modeltrans - Translate model fields using a JSONField — django-modeltrans 0.2.1 documentation

# django-modeltrans - Translate model fields using a `JSONField`

- Uses one `django.contrib.postgres.JSONField` (PostgreSQL jsonb field) for every record.
- Django 1.11 and 2.0 (with their supported python versions)
- PostgreSQL >= 9.5 and Psycopg2 >= 2.5.4.

About the app:

- Available on pypi
- Tested using Travis CI
- Documentation on readthedocs.org
- Bug tracker

## Table of contents

Documentation

- Getting started
- Database performance
- Inner workings
- Known issues
- Related packages
- Management commands
- Admin support

Reference

- API Reference
- Settings Reference
- Migrating from django-modeltranslation
- django-modeltrans change log